package com.yanzhu.project.service;

import java.util.List;
import com.yanzhu.project.domain.ProProjectInfo;

/**
 * 项目信息Service接口
 * 
 * @author yanZhu
 * @date 2024-02-23
 */
public interface IProProjectInfoService 
{
    /**
     * 查询项目信息
     * 
     * @param id 项目信息主键
     * @return 项目信息
     */
    public ProProjectInfo selectProProjectInfoById(Long id);

    /**
     * 查询项目信息列表
     * 
     * @param proProjectInfo 项目信息
     * @return 项目信息集合
     */
    public List<ProProjectInfo> selectProProjectInfoList(ProProjectInfo proProjectInfo);

    /**
     * 新增项目信息
     * 
     * @param proProjectInfo 项目信息
     * @return 结果
     */
    public int insertProProjectInfo(ProProjectInfo proProjectInfo);

    /**
     * 修改项目信息
     * 
     * @param proProjectInfo 项目信息
     * @return 结果
     */
    public int updateProProjectInfo(ProProjectInfo proProjectInfo);

    /**
     * 批量删除项目信息
     * 
     * @param ids 需要删除的项目信息主键集合
     * @return 结果
     */
    public int deleteProProjectInfoByIds(Long[] ids);

    /**
     * 删除项目信息信息
     * 
     * @param id 项目信息主键
     * @return 结果
     */
    public int deleteProProjectInfoById(Long id);
}
